@@ -125,25 +125,52 @@ class GraphView{
             event.stopPropagation();
         } )
 
-        //SHIFT+D event handling for duplicate/copy here
+        // XGEE key listener
         editorDOM.addEventListener('keydown', async (event) => { 
-            if(event.shiftKey && event.key === 'D')
-            {               
-                var selectedCells=self.graph.getSelectionCells();
-                if(selectedCells.length)
+
+                  
+            var target={};
+            target.editorId=self.graphController.model.editorId;
+            target.DOM=null
+            target.graphObject=null;
+            target.originalEvent=event
+
+            var selectedCells=self.graph.getSelectionCells();
+            // TODO: support multiple selected cells
+
+            // Single selected cell
+            if(selectedCells.length == 1)
+            {  
+                var cell=selectedCells[0]
+                target.isCanvas=false;
+                target.isGraphObject=true;  
+                target.graphObject=cell.value;  
+                target.isVertex=selectedCells[0].value instanceof Vertex;
+                target.isEdge=selectedCells[0].value instanceof Edge;      
+                target.eObject=target.graphObject.getEObject();   
+                if(target.isVertex)
                 {
-                    let cell=selectedCells[0]
-                    let copy=await ecoreSync.clone(cell.value.getEObject());        
-                    let pos=cell.value.getPosition()
-                    pos.x+=cell.value.getSize().x
-                    pos.y+=cell.value.getSize().y             
-                    self.graphController.paste(copy,cell.value.parent.getEObject(),pos)
-                     this.graph.setSelectionCells(cells);
-                }
-                event.stopPropagation();
+                    target.position=cell.value.getPosition()
+                }        
+                if(target.isEdge)
+                {
+                    target.edgeSource=cell.source.value
+                    target.edgeTarget=cell.target.value
+                } 
             }
-            
-           
+
+            // No selected cell
+            if(selectedCells.length == 0)
+            {
+                target.isCanvas=true
+                target.isGraphObject=false;
+                target.isVertex=false;
+                target.isEdge=false;
+                target.eObject=self.graphController.eObject
+            }                                 
+
+            event.stopPropagation();      
+            self.eventBroker.publish('XGEE/KEYPRESS',{target:target,eObject:null,DOM:null,key:event.key, shiftKey:event.shiftKey, ctrlKey: event.ctrlKey, altKey: event.altKey})
         } )
 
         //Context Menu on Right-Click
@@ -391,6 +418,9 @@ class GraphView{
 
 
         this.outline=new GraphViewPortOutline(this.viewPort,outlineDOM)
+
+        //Grab focus
+        editorDOM.focus()
     }
 
 
